@@ -468,6 +468,15 @@ _terms = {
     "KISAO_0000682": "allow approximation",
     "KISAO_0000683": "relative tolerance for approximation",
     "KISAO_0000684": "number of steps per output",
+    "KISAO_0000685": "biological state optimization method",
+    "KISAO_0000686": "Enzyme Cost Minimization",
+    "KISAO_0000687": "Max-min Driving Force method",
+    "KISAO_0000688": "type of system described",
+    "KISAO_0000689": "mathematical system",
+    "KISAO_0000690": "biological system",
+    "KISAO_0000691": "metabolic system",
+    "KISAO_0000692": "cellular system",
+    "KISAO_0000693": "biochemical system",
     "KISAO_0000800": "systems property",
     "KISAO_0000801": "concentration control coefficient matrix (unscaled)",
     "KISAO_0000802": "control coefficient (scaled)",
@@ -2390,6 +2399,42 @@ class KISAO(str, Enum):
     KISAO_0000684 = "KISAO_0000684"
     NUMBER_OF_STEPS_PER_OUTPUT = "KISAO_0000684"
 
+    # biological state optimization method
+    KISAO_0000685 = "KISAO_0000685"
+    BIOLOGICAL_STATE_OPTIMIZATION_METHOD = "KISAO_0000685"
+
+    # Enzyme Cost Minimization
+    KISAO_0000686 = "KISAO_0000686"
+    ENZYME_COST_MINIMIZATION = "KISAO_0000686"
+
+    # Max-min Driving Force method
+    KISAO_0000687 = "KISAO_0000687"
+    MAX_MIN_DRIVING_FORCE_METHOD = "KISAO_0000687"
+
+    # type of system described
+    KISAO_0000688 = "KISAO_0000688"
+    TYPE_OF_SYSTEM_DESCRIBED = "KISAO_0000688"
+
+    # mathematical system
+    KISAO_0000689 = "KISAO_0000689"
+    MATHEMATICAL_SYSTEM = "KISAO_0000689"
+
+    # biological system
+    KISAO_0000690 = "KISAO_0000690"
+    BIOLOGICAL_SYSTEM = "KISAO_0000690"
+
+    # metabolic system
+    KISAO_0000691 = "KISAO_0000691"
+    METABOLIC_SYSTEM = "KISAO_0000691"
+
+    # cellular system
+    KISAO_0000692 = "KISAO_0000692"
+    CELLULAR_SYSTEM = "KISAO_0000692"
+
+    # biochemical system
+    KISAO_0000693 = "KISAO_0000693"
+    BIOCHEMICAL_SYSTEM = "KISAO_0000693"
+
     # systems property
     KISAO_0000800 = "KISAO_0000800"
     SYSTEMS_PROPERTY = "KISAO_0000800"
